@@ -84,15 +84,39 @@ View::View(Config &cfg, ClientGame &_cg)
  * t is theme name, r=0 means fullscreen, otherwise vertical resolution. */
 void View::init(string t, uint r)
 {
+	int cpdix = 0; /* default to display 0 */
+
 	_loginfo("Initializing View (Theme=%s, Resolution=%d)\n",t.c_str(),r);
 
+	/* get current display index or default to 0 */
+	if (mw) {
+		cpdix = mw->getDisplayIndex();
+	} else if (SDL_GetNumVideoDisplays() > 1) {
+		/* XXX first time we open the window, so to properly determine the
+		 * current display we open a small window for multiple monitors */
+		SDL_Window *testwindow;
+		_loginfo("Multiple displays detected\n");
+		if((testwindow = SDL_CreateWindow("LBreakoutHD",
+					SDL_WINDOWPOS_CENTERED,
+					SDL_WINDOWPOS_CENTERED,
+					320, 200, 0)) == NULL) {
+			_logerr("Could not open display test window: %s\n",
+								SDL_GetError());
+			_loginfo("Falling back to settings of display 0\n");
+		} else {
+			cpdix = SDL_GetWindowDisplayIndex(testwindow);
+			SDL_DestroyWindow(testwindow);
+		}
+	}
+	_loginfo("Using display %d\n",cpdix);
+
 	/* determine resolution and scale factor */
 	int sw, sh;
 	if (r == 0) {
 		/* fullscreen is tricky... might also be 16:10,4:3,...
 		 * use width to get 16:9 leaving space at bottom */
 		SDL_DisplayMode mode;
-		SDL_GetCurrentDisplayMode(0,&mode);
+		SDL_GetCurrentDisplayMode(cpdix,&mode);
 		/* TEST  mode.w = 1600; mode.h = 1200; */
 		sw = mode.w;
 		sh = mode.w/16*9;
@@ -189,9 +213,15 @@ View::~View()
 	theme.fMenuFocus.free();
 
 #ifdef WIN32
-	/* in windows saving in destructor does not work on exit */
+	/* XXX after the view object clientgame and config get destructed which
+	 * works in linux and saves hiscores and config. however, in windows
+	 * destructing some sub object in clientgame seg faults. the hiscore's
+	 * dtor is never called (and so is clientgame's dtor) so we explicitly
+	 * save hiscores and config here. if anyone knows why: let me know. */
+	cgame.saveHiscores();
 	config.save();
 #endif
+
 	_loginfo("Finalizing SDL\n");
 	TTF_Quit();
 	SDL_Quit();
@@ -586,7 +616,7 @@ void View::render()
 	}
 
 	/* shine effect */
-	if (cgame.isBrickAtPosition(shineX,shineY))
+	if (shineX != -1 && cgame.isBrickAtPosition(shineX,shineY))
 		theme.shine.copy(shineFrameCounter.get(),0,
 			shineX*brickScreenWidth,
 			shineY*brickScreenHeight);
